#!/usr/bin/perl

######################################################################
# isr_srv_resetcache.pl - Clears the serverside cache
#
# $Id: isr_srv_resetcache.pl,v 1.4 2004/11/05 18:52:39 droh Exp $
######################################################################

#
#                  Internet Suspend/Resume (Release 0.5)
#           A system for capture and transport of PC state
#
#              Copyright (c) 2002-2004, Intel Corporation
#            Copyright (c) 2004, Carnegie Mellon University
#                         All Rights Reserved
#
# This software is distributed under the terms of the Eclipse Public
# License, Version 1.0 which can be found in the file named LICENSE.
# ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS SOFTWARE CONSTITUTES
# RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT
#

###################
# Prologue
###################
use strict;
use Getopt::Std;
use lib "/usr/local/isr/bin";
use Server;
$| = 1; # Autoflush output on every print statement

####################
# Begin main routine
####################

# 
# Local variables
#
my $parceldir;
my $lastdir;
my $lastver;
my $numdirs;
my $i;

my @files;

#
# Parse the command line args
#
no strict 'vars';
getopts('hp:');

if ($opt_h) {
    usage();
}
if (!$opt_p) {
    usage("Missing parcel path (-p)");
}
$parceldir = "$Server::CONTENT_ROOT" . "$opt_p";
use strict 'vars';

#
# Make sure the parcel directory exists
#
(-e $parceldir)
    or errexit("$parceldir does not exist");

opendir(DIR, $parceldir)
    or errexit("Could not open directory $parceldir");
@files = reverse sort grep(/^\d+$/, readdir(DIR)); 
closedir(DIR);

$lastver = int(@files[0]);
$lastdir = "$parceldir/" . sprintf("%06d", $lastver);
$numdirs = get_value("$lastdir/hdk/index.lev1", "NUMDIRS");

system("rm -rf $parceldir/cache");
system("mkdir $parceldir/cache");
system("mkdir $parceldir/cache/hdk");

for ($i = 0; $i < $numdirs; $i++) {
    my $dirname = sprintf("%04d", $i);
    system("mkdir $parceldir/cache/hdk/$dirname");
}

exit 0;

##################
# end main routine
##################

#
# usage - print help message and terminate
#
sub usage
{
    my $msg = shift;
    my $progname;

    # Strip any path information from the program name
    ($progname = $0) =~ s#.*/##s; 

    if ($msg) {
        print "$progname: $msg\n\n";
    }
                                                                                
    print "Usage: $progname [-h] -p <parcel path>\n";
    print "Options:\n";
    print "  -h    Print this message\n";    
    print "  -p    Relative parcel path (userid/parcel)\n";    
    print "\n";
    exit 0;
}
